@@ -5,7 +5,7 @@ context("updateAwesomeCheckboxGroup")
 test_that("Send message", {
 
   session <- as.environment(list(
-    ns = function(x) {x},
+    ns = identity,
     sendInputMessage = function(inputId, message) {
       session$lastInputMessage = list(id = inputId, message = message)
     }
